
body{
    margin: 0px;
}

#borderContainer{
    border: 1px solid #ccc;
    overflow-x: clip;
    overflow-y: scroll;
    padding-left: 10px;
    padding-right: 10px;
}

#borderContainer .messageRow{
    display: flex;
    flex-direction: row;
    gap: 5px;
    margin-top: 10px;
    margin-bottom: 10px;
}


#borderContainer .messageRow .avator{
    text-align: center;
    word-break: break-all;
    width: 40px;
    height: 40px;
    display: flex;
    justify-content: center;
    align-items: center;
    font-size: 12px;
    background-color: cornflowerblue;
    border-radius: 50%;
}
#borderContainer .messageRow .imgBox{
    width: 0px;
    flex: 1;
}
#borderContainer .messageRow .imgBox img{
    width: 100%;
}

#borderContainer .messageRow .questionBox p{
    margin-top: 0px;
    text-decoration: none;
}

#borderContainer .messageRow .questionBox{
    width: 0px;
    flex: 1;
    padding: 12px 15px;
    background-color: var(--fill-2, #F4F5F9);
    border-radius: 8px;
}


#borderContainer .responseRow{
    display: flex;
    flex-direction: row-reverse;
    gap: 5px;
    margin-top: 10px;
    margin-bottom: 10px;
}

#borderContainer .responseRow .rebotAvator{
    text-align: center;
    word-break: break-all;
    width: 40px;
    height: 40px;
    display: flex;
    justify-content: center;
    align-items: center;
    font-size: 12px;
    background-color: yellowgreen;
    border-radius: 50%;
}

#borderContainer .responseRow .responseBox{
    width: 0px;
    flex: 1;
    padding: 12px 15px;
    background-color: rgba(39,45,230,.1);
    border-radius: 8px;
}

#borderContainer .responseRow .responseBox p{
    margin-top: 0px;
    text-decoration: none;
}

#borderContainer .responseRow .imgBox{
    width: 0px;
    flex: 1;
}

#borderContainer .responseRow .imgBox img{
    width: 100%;
}

::-webkit-scrollbar {
    width: 8px;
    background: rgb(240, 242, 246);

}
::-webkit-scrollbar-thumb {
    border-radius: 90px;
    background:  rgb(240, 242, 246);
}
::-webkit-scrollbar-track {
    -webkit-box-shadow: inset 0 0 4px  rgb(240, 242, 246);
    border-radius: 90px;
    background:  rgb(240, 242, 246);
    opacity: 0;
}
:hover::-webkit-scrollbar-thumb {
    background: #D7D8DD;
}